@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="tr" sourcelanguage="en_US">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr" sourcelanguage="en_US">
 <context>
     <name>AlbumDefaultPage</name>
     <message>
@@ -1384,4 +1382,4 @@ Lirik dosyasını (şarkıya eşit isimli) ve şarkıyı içeren dosyaları ayn
         <translation>Ara</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
